@@ -2,13 +2,13 @@
 use strict;
 use warnings;
 
-use Win32::GUI;
+use Win32::GUI();
 
 my $main = Win32::GUI::Window->new(
-	-name => 'Main',
-	-text => 'Perl',
-	-width => 200,
-       	-height => 200
+    -name => 'Main',
+    -text => 'Perl',
+    -width => 200,
+    -height => 200
 );
 
 $main->Show();
@@ -16,5 +16,5 @@ Win32::GUI::Dialog();
 exit(0);
 
 sub Main_Terminate {
-	return -1;
+    return -1;
 }
